@@ -13,25 +13,27 @@ from pathlib import Path
 import pickle
 from typing import Any, Final, Iterable, Iterator, Optional, Type
 
-from ._config import AbstractConfig
+from .types import ClackConfig, Config_T
 
 
 _CODECS_ENCODING: Final = "base64"
-_NO_CONFIG_FILE: Final = "DEFAULT_CLACK_CONFIG_FILE_LIST"
+_NOT_SET: Final = "CLACK_ENVVAR_NOT_SET"
 
 
 @contextmanager
 def clack_envvars_set(
     app_name: str,
-    config_types: Iterable[Type[AbstractConfig]],
+    config_types: Iterable[Type[ClackConfig]],
     *,
     config_file: Path = None,
+    cfg: ClackConfig = None,
 ) -> Iterator[None]:
     """Context manager that sets temporary envvars.
 
     The following envvars are set on __enter__ and removed on __exit__:
         - CLACK_APP_NAME
         - CLACK_CONFIG_DEFAULTS
+        - CLACK_CONFIG_DICT
         - CLACK_CONFIG_FILE
     """
     config_defaults = {}
@@ -41,23 +43,29 @@ def clack_envvars_set(
         )
         config_defaults.update(some_config_defaults)
 
+    cfg_dict = cfg.dict() if cfg is not None else {}
+
     os.environ["CLACK_APP_NAME"] = app_name
     os.environ["CLACK_CONFIG_DEFAULTS"] = codecs.encode(
         pickle.dumps(config_defaults), _CODECS_ENCODING
     ).decode()
+    os.environ["CLACK_CONFIG_DICT"] = codecs.encode(
+        pickle.dumps(cfg_dict), _CODECS_ENCODING
+    ).decode()
     os.environ["CLACK_CONFIG_FILE"] = (
-        _NO_CONFIG_FILE if config_file is None else str(config_file)
+        _NOT_SET if config_file is None else str(config_file)
     )
 
     yield
 
     del os.environ["CLACK_APP_NAME"]
     del os.environ["CLACK_CONFIG_DEFAULTS"]
+    del os.environ["CLACK_CONFIG_DICT"]
     del os.environ["CLACK_CONFIG_FILE"]
 
 
 def _config_defaults_from_config_type(
-    config_type: Type[AbstractConfig],
+    config_type: Type[ClackConfig],
 ) -> dict[str, Any]:
     result = {}
     for key, value in config_type.__fields__.items():
@@ -100,12 +108,34 @@ def get_config_file() -> Optional[Path]:
     with _catch_key_error("get_config_file"):
         config_file = os.environ["CLACK_CONFIG_FILE"]
 
-    if config_file == _NO_CONFIG_FILE:
+    if config_file == _NOT_SET:
         return None
     else:
         return Path(config_file)
 
 
+def get_config(cfg_type: Type[Config_T]) -> Optional[Config_T]:
+    """Returns a clack configuration object of type `cfg_type`.
+
+    WARNING: This function should probably only be used when there is no way to
+    pass the config object directly to the calling function.
+
+    Raises:
+        A RuntimeError if the CLACK_CONFIG_DICT envvar is not defined.
+    """
+    with _catch_key_error("get_config"):
+        clack_config_dict = os.environ["CLACK_CONFIG_DICT"]
+
+    cfg_dict = pickle.loads(
+        codecs.decode(clack_config_dict.encode(), _CODECS_ENCODING)
+    )
+
+    if cfg_dict == _NOT_SET:
+        return None
+    else:
+        return cfg_type(**cfg_dict)
+
+
 @contextmanager
 def _catch_key_error(func_name: str) -> Iterator[None]:
     try:
