@@ -3,22 +3,10 @@
 from __future__ import annotations
 
 import argparse
-from typing import Any, List, Protocol
+from typing import Any, Callable, List, Mapping, MutableSequence
 
 from ._parser import monkey_patch_parser
-
-
-class NewCommand(Protocol):
-    """Type of the function returned by `new_command_factory()`."""
-
-    def __call__(
-        self,
-        name: str,
-        *,
-        help: str,  # pylint: disable=redefined-builtin
-        **kwargs: Any,
-    ) -> argparse.ArgumentParser:
-        """This method captures the `new_command()` function's signature."""
+from .types import ClackNewCommand, ClackRunner
 
 
 def new_command_factory(
@@ -28,7 +16,7 @@ def new_command_factory(
     required: bool = True,
     description: str = None,
     **kwargs: Any,
-) -> NewCommand:
+) -> ClackNewCommand:
     """Returns a `new_command()` function that can be used to add subcommands.
 
     Args:
@@ -63,6 +51,48 @@ def new_command_factory(
     return new_command
 
 
+def register_runner_factory(
+    mut_runner_registry: MutableSequence[ClackRunner],
+) -> Callable[[ClackRunner], ClackRunner]:
+    """Creates a decorator that can be used to register runner functions."""
+
+    def register_runner(runner: ClackRunner) -> ClackRunner:
+        mut_runner_registry.append(runner)
+        return runner
+
+    return register_runner
+
+
+def filter_cli_args(
+    args: argparse.Namespace | Mapping[str, Any]
+) -> dict[str, Any]:
+    """Filters args produced by 'parser' passed into clack.main_factory().
+
+    Used to filter out argparse arguments which were NOT specified on the
+    command-line.
+    """
+    from . import _dynvars as dyn
+    from ._parser import ARGPARSE_ARGUMENT_DEFAULT
+
+    if not isinstance(args, argparse.Namespace):
+        kwargs = args
+    else:
+        kwargs = vars(args)
+
+    config_defaults = dyn.get_config_defaults()
+
+    result = {}
+    for key, value in kwargs.items():
+        if key in config_defaults and config_defaults[key] == value:
+            continue
+
+        if value is ARGPARSE_ARGUMENT_DEFAULT:
+            continue
+
+        result[key] = value
+    return result
+
+
 class comma_list_or_file:
     """Namespace class for comma list CLI arguments.
 
